import { stringifyEntityRef } from '@backstage/catalog-model';

class BatchLoader {
  constructor(options) {
    this.logger = options.logger;
    this.manager = options.databaseManager;
    this.client = this.manager.forPlugin("catalog").getClient();
  }
  async getEntitiesByRefs(refs) {
    this.logger.info(`Loading entities for refs: ${refs}`);
    const client = await this.client;
    const stringifiedRefs = refs.map((ref) => typeof ref === "string" ? ref : stringifyEntityRef(ref));
    const rows = await client("final_entities").select("final_entity as entity", "refresh_state.entity_ref as ref").join(client.raw("refresh_state ON refresh_state.entity_id = final_entities.entity_id")).whereIn("refresh_state.entity_ref", stringifiedRefs);
    const unsortedEntities = new Map(rows.map((row) => [row.ref, JSON.parse(row.entity)]));
    const entities = stringifiedRefs.map((ref) => unsortedEntities.get(ref));
    this.logger.info(`Loaded ${entities.length} entities`);
    return entities;
  }
}

export { BatchLoader };
//# sourceMappingURL=index.esm.js.map
